@@ -76,7 +76,7 @@ qpv->setWhatsThis(
     "restricts visible Q-peaks to values above this threshold. A renewed left click on the black box at the bottom displays all Q-peaks "
     "again. If you hide this all Q-Peaks get colored the same.");
 
-chgl->setWhatsThis(
+container->setWhatsThis(
     "<h1>Structure Viewer</h1><p> Displays the structure in the selected drawing mode. The molecule can be rotated "
     "(hold left mouse button), zoomed (hold right mouse button) and moved (hold middle mouse button). Left click on "
     "atoms moves the cursor in the .ins/.res window to this atom, while additional atom information is reported in "
@@ -146,13 +146,13 @@ killHs->setWhatsThis(
 togAtom->setWhatsThis(
     "<h1>Toggle atoms </h1><p><img width=\"64\" src=\""+theIconPath+"atoms.svg\"><p> Toggle drawing of atoms on/off.");
 
-tubeStyle->setWhatsThis(
+chgl->tubes->setWhatsThis(
     "<h1>Tube model </h1><p><img width=\"64\" src=\""+theIconPath+"tubes.svg\"><p> Switch structure representation to tube mode.");
 
-ballStyle->setWhatsThis(
+chgl->ballStick->setWhatsThis(
     "<h1>Ball and stick model </h1><p><img width=\"64\" src=\""+theIconPath+"ballstick.svg\"><p> Switch structure representation to ball and stick mode.");
 
-togElli->setWhatsThis(
+chgl->adp->setWhatsThis(
     "<h1>Toggle ADPs</h1><p><img width=\"64\" src=\""+theIconPath+"adp.svg\"><p> Toggles atom drawing between isotropic and anisotropic "
     "atomic displacement parameter mode.");
 
@@ -162,10 +162,10 @@ togBond->setWhatsThis(
 togLabel->setWhatsThis(
     "<h1>Toggle labels</h1><p><img width=\"64\" src=\""+theIconPath+"labels.svg\"><p> Toggle atom labels on/off.");
 
-togUnit->setWhatsThis(
+chgl->togUnit->setWhatsThis(
     "<h1>Toggle unit cell</h1><p><img width=\"64\" src=\""+theIconPath+"unitcell.svg\"><p> Toggle unit cell on/off");
 
-togHBond->setWhatsThis(
+chgl->h_bonds->setWhatsThis(
     "<h1>Toggle H-bonds</h1><p><img width=\"64\" src=\""+theIconPath+"hbrs.svg\"><p> Toggle hydrogen bonds on/off");
 
 chgl->atomLegend->setWhatsThis(
@@ -174,7 +174,7 @@ chgl->atomLegend->setWhatsThis(
 chgl->toggleDockWidgets->setWhatsThis(
     "<h1>Hide text window</h1><p><img width=\"64\" src=\""+theIconPath+"hidedockwdg.svg\"><p> Hide text windows and maximize structure viewer");
 
-toggleOrthoView->setWhatsThis(
+chgl->toggleOrthoView->setWhatsThis(
     "<h1>Toggle projection mode</h1><p><img width=\"64\" src=\""+theIconPath+"ortho.svg\"><p> Toggle between orthographic and perspective projection mode");
 
 chgl->grow->setWhatsThis(
@@ -188,7 +188,7 @@ chgl->fuse->setWhatsThis(
 chgl->qPeakBonds->setWhatsThis(
     "<h1>Q-Peak bonds</h1><p><img width=\"64\" src=\""+theIconPath+"qbond.svg\"><p> Toggle the drawing of bond to and between Q-Peaks on/off");
 
-chgl->hideh->setWhatsThis(
+chgl->hideHydrogen->setWhatsThis(
     "<h1>Hydrogens</h1><p><img width=\"64\" src=\""+theIconPath+"hideh.svg\"><p> Toggle hydrogen atom drawing on/off");
 
 chgl->shpm1->setWhatsThis(
@@ -377,7 +377,7 @@ this->setWhatsThis(
         <td> Select atoms in a rectangular region.</td></tr>\
 </table><HR><b>Wheel</b> = Mousewheel");
 
-#else                 
+#else
 quickReLoadButton->setWhatsThis(
         "<h1>Quick-Re-Load</h1><p><img width=\"128\" src=\""+theIconPath+"quick-re-load.svg\">"
         "<p> If <b> Quick-Re-Load </b> is checked the structure gets just updated instead of fully fresh reloaded. "
@@ -388,14 +388,12 @@ wghtRefineAct->setWhatsThis(
     " <p> <b>shelxl</b> recommends a new <b>WGHT</b>ing scheme after every run. This function uses "
     " the recommended scheme and starts a refinement and repeats until the scheme converges, or if "
     " it does not, after a maximum of ten attempts.");
-
 chgl->hideBeLo->setWhatsThis(
     "<h1>Toggle BEDE and LONE objects (IDEAL)</h1><p><img width=\"64\" src=\""+theIconPath+"ideal.svg\"> "
     "<p> The IDEAL (<b>I</b>nvariom <b>D</b>erived <b>E</b>lectron <b>A</b>na<b>L</b>ysis) feature describes the asphericity "
     "of the atomic electron density by adding small Gaussian distributions to chemical bonds and to lone pairs while the same "
     "amount is subtracted at the atom core. At the position of such a Gaussian distribution SheXle draws a triacontahedron. "
     "<p> By clicking on <b>'Toggle BEDE and LONE objects (IDEAL)'</b> you can hide these triacontahedra.");
-
 chgl->clearSelection->setWhatsThis(
     "<h1>Deselect</h1><p><img width=\"64\" src=\""+theIconPath+"deselect.svg\"><p> Deselect all atoms.");
 
@@ -452,14 +450,12 @@ qpv->setWhatsThis(
     "<h1>Q-Peak Legend <img width=\"64\" src=\""+theIconPath+"qlegend.svg\"> </h1><p> Displays the color scale for the Q-peaks. Left click on the color bar "
     "restricts visible Q-peaks to values above this threshold. A renewed left click on the black box at the bottom displays all Q-peaks "
     "again. If you hide this all Q-Peaks get colored the same.");
-
 chgl->setWhatsThis(
     "<h1>Structure Viewer</h1><p> Displays the structure in the selected drawing mode. The molecule can be rotated "
     "(hold left mouse button), zoomed (hold right mouse button) and moved (hold middle mouse button). Left click on "
     "atoms moves the cursor in the .ins/.res window to this atom, while additional atom information is reported in "
     "the information window. Distances and angles are measured by selecting multiple atoms and reported in the information "
     "window. Additional actions/options and settings are accessible by right click on atoms.");
-
 refineAct->setWhatsThis(
     "<h1>Run ShelXL</h1><p><img width=\"64\" src=\""+theIconPath+"refine.svg\"><p> Copy .res to .ins and run ShelXL");
 
@@ -481,7 +477,6 @@ screenshotAct->setWhatsThis(
 actionSave->setWhatsThis(
     "<h1>Save </h1><p><img width=\"64\" src=\""+theIconPath+"filesave.svg\"><p>Saves the .res files and synchronizes the structure view with the "
     "editor content.");
-
 fxle->mapcontrol->setWhatsThis(
     "<h1>Open map control </h1><p><img width=\"64\" src=\""+theIconPath+"mapcontrol.svg\"><p> Open the Fo and Fo-Fc map control dialog. "
     "In this menu the settings for Fo and Fo-Fc map calculation and representation can be adjusted.");
@@ -522,38 +517,29 @@ killHs->setWhatsThis(
 
 togAtom->setWhatsThis(
     "<h1>Toggle atoms </h1><p><img width=\"64\" src=\""+theIconPath+"atoms.svg\"><p> Toggle drawing of atoms on/off.");
-
-tubeStyle->setWhatsThis(
+chgl->tubes->setWhatsThis(
     "<h1>Tube model </h1><p><img width=\"64\" src=\""+theIconPath+"tubes.svg\"><p> Switch structure representation to tube mode.");
 
-ballStyle->setWhatsThis(
+chgl->ballStick->setWhatsThis(
     "<h1>Ball and stick model </h1><p><img width=\"64\" src=\""+theIconPath+"ballstick.svg\"><p> Switch structure representation to ball and stick mode.");
 
-togElli->setWhatsThis(
+chgl->adp->setWhatsThis(
     "<h1>Toggle ADPs</h1><p><img width=\"64\" src=\""+theIconPath+"adp.svg\"><p> Toggles atom drawing between isotropic and anisotropic "
     "atomic displacement parameter mode.");
-
 togBond->setWhatsThis(
     "<h1>Toggle bonds</h1><p><img width=\"64\" src=\""+theIconPath+"bonds.svg\"><p> Toggles bond drawing on/off.");
-
 togLabel->setWhatsThis(
     "<h1>Toggle labels</h1><p><img width=\"64\" src=\""+theIconPath+"labels.svg\"><p> Toggle atom labels on/off.");
-
-togUnit->setWhatsThis(
+chgl->togUnit->setWhatsThis(
     "<h1>Toggle unit cell</h1><p><img width=\"64\" src=\""+theIconPath+"unitcell.svg\"><p> Toggle unit cell on/off");
-
-togHBond->setWhatsThis(
+chgl->h_bonds->setWhatsThis(
     "<h1>Toggle H-bonds</h1><p><img width=\"64\" src=\""+theIconPath+"hbrs.svg\"><p> Toggle hydrogen bonds on/off");
-
 chgl->atomLegend->setWhatsThis(
     "<h1>Toggle Atom Legend  </h1><p><img width=\"64\" src=\""+theIconPath+"legend.svg\"><p> An atom type legend is shown on the lower left of the view.");
-
 chgl->toggleDockWidgets->setWhatsThis(
     "<h1>Hide text window</h1><p><img width=\"64\" src=\""+theIconPath+"hidedockwdg.svg\"><p> Hide text windows and maximize structure viewer");
-
-toggleOrthoView->setWhatsThis(
+chgl->toggleOrthoView->setWhatsThis(
     "<h1>Toggle projection mode</h1><p><img width=\"64\" src=\""+theIconPath+"ortho.svg\"><p> Toggle between orthographic and perspective projection mode");
-
 chgl->grow->setWhatsThis(
     "<h1>Toggle FUSE/GROW <img width=\"64\" src=\""+theIconPath+"grow.svg\"><img width=\"64\" src=\""+theIconPath+"fuse.svg\"> </h1> Toggle structure representation between "
     "asymmetric unit cell content (FUSE) and content completed by symmetry (GROW)");
@@ -565,12 +551,11 @@ chgl->fuse->setWhatsThis(
 chgl->qPeakBonds->setWhatsThis(
     "<h1>Q-Peak bonds</h1><p><img width=\"64\" src=\""+theIconPath+"qbond.svg\"><p> Toggle the drawing of bond to and between Q-Peaks on/off");
 
-chgl->hideh->setWhatsThis(
+chgl->hideHydrogen->setWhatsThis(
     "<h1>Hydrogens</h1><p><img width=\"64\" src=\""+theIconPath+"hideh.svg\"><p> Toggle hydrogen atom drawing on/off");
 
 chgl->shpm1->setWhatsThis(
     "<h1>Hide PART -N</h1><p><img width=\"64\" src=\""+theIconPath+"part-1.svg\"><p>Hide PART -N symmetry equivalent as ghost atoms");
-
 chgl->highlightParts->setWhatsThis(
     "<h1>Highlight PARTs</h1><p><img width=\"64\" src=\""+theIconPath+"parts.svg\"><p> Highlight structure fragments in dependence of their PART membership.");
 
@@ -580,7 +565,6 @@ enterRenameMode->setWhatsThis(
 
 chgl->invertMouseZoom->setWhatsThis(
     "<h1>Invert mouse zoom </h1><p><img width=\"64\" src=\""+theIconPath+"invzoom.svg\"><p> Invert the mouse move direction for zoom-in and zoom-out.");
-
 homeMe->setWhatsThis(
     "<h1>Move molecules home </h1><p><img width=\"64\" src=\""+theIconPath+"home.svg\"><p> Moves molecule back to the default center of rotation. You can move the "
     "structure dragging the middle mouse button.");
