@@ -71,6 +71,7 @@ class QSize;
 class QCompleter;
 class QWidget;
 class ChGL;
+class PlayOpenGL;
 QT_END_NAMESPACE
 
 class LineNumberArea;
@@ -236,6 +237,7 @@ protected:
     void contextMenuEvent(QContextMenuEvent *event);
     void focusOutEvent(QFocusEvent *e);
     void paintEvent(QPaintEvent *);
+
 public slots:
     void testCpd();
     void mpaste();
@@ -302,9 +304,16 @@ public slots:
     void lineNumberToggled(QMouseEvent *event);//!< when the LineNumberArea is clicked the comment state of the secified line is toggled.
     void remark(int line);//!< toggles the comment state of the secified line. @param line The line number in file
     void toggleRemarks();//!< toggleRemarks toggles the comment state of the selected lines.
+    /*
     void setgl(ChGL *g){
       chgl=g;
     }//!< setgl passes the ChGL widget to the CodeEditor
+    // */
+    //*
+    void setgl(PlayOpenGL *g){
+        chgl=g;
+    }
+    // */
 
 private:
     QString selectedRestraintsAtoms(QString buffer, QList<MyAtom> selected, QString resiSpec, bool exclude_H=false);
@@ -312,11 +321,34 @@ private:
     QWidget *lineNumberArea;
     QCompleter *c;
     QWidget *afixHighlightArea;
-    ChGL *chgl;
+    //ChGL *chgl;
+    PlayOpenGL *chgl;
     bool cbhandled=true;
     MultiTextCursor m_cursors;
     bool startMouseMoveCursor1;
     double cromerMann(double sintl, double a1, double b1,  double a2,  double b2, double a3, double b3, double a4, double b4, double c);
+    const QRegularExpression spaces = QRegularExpression("\\s+");
+    const QRegularExpression comments = QRegularExpression("^REM",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression onlydigits = QRegularExpression("^[0-9]+$");
+    const QRegularExpression nodigits = QRegularExpression("\\D");
+    const QRegularExpression digits = QRegularExpression("\\d+");
+    const QRegularExpression plusfloat = QRegularExpression("[.0-9]+");
+    const QRegularExpression grossbuch = QRegularExpression("^[A-Z]");
+    const QRegularExpression onlysmall = QRegularExpression("^[a-z]$");
+    const QRegularExpression linecontinue = QRegularExpression("^[0-9]+");
+    const QRegularExpression listinst = QRegularExpression("\nLIST",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression unitinst = QRegularExpression("^UNIT",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression actainst = QRegularExpression("^ACTA",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression sfacinst = QRegularExpression("^SFAC",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression hklfinst = QRegularExpression("^HKLF",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression extiinst = QRegularExpression("^EXTI",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression confinst = QRegularExpression("^CONF",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression omithklinst = QRegularExpression("^OMIT\\s+\\d+\\s+\\d+\\s+\\d+");
+    const QRegularExpression afix0inst = QRegularExpression("^AFIX\\s+0",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression afixinst = QRegularExpression("^AFIX\\s+\\d+",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression part0inst = QRegularExpression("^PART\\s+0",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression partinst = QRegularExpression("^PART\\s+[-0-9]{1,}",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression startsmall = QRegularExpression("^[a-z]+");
 };
 
 /////////////////////////////////////////////////
