@@ -3,8 +3,10 @@
 #define XLEDEPR_H 1
 #if (QT_VERSION >= 0x050e00)
 #define skipEmptyParts Qt::SkipEmptyParts
+#define keepEmptyParts Qt::KeepEmptyParts
 #else
 #define skipEmptyParts QString::SkipEmptyParts
+#define keepEmptyParts QString::KeepEmptyParts
 #endif
 
 #endif
