@@ -1,5 +1,7 @@
 #include "dragdropatomsdlg.h"
-#include "deprecation.h"
+#include <QDialogButtonBox>
+#include <QHBoxLayout>
+#include <QLineEdit>
 DragDropAtomsDialog::DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<int> &reference, QList<int> *target, QWidget *parent)
     :QDialog(parent){
     chgl=gl;
@@ -32,7 +34,7 @@ DragDropAtomsDialog::DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<i
     QLabel *resiResiClassL = new QLabel("Residue Class:");
     resiResiClass = new QLineEdit("");
     resiResiClass->setMaxLength(4);
-    resiResiClass->setValidator(new QRegExpValidator(QRegExp("^[A-Za-z]\\w{0,3}"),resiResiClass));
+    resiResiClass->setValidator(new QRegularExpressionValidator(QRegularExpression("^[A-Za-z]\\w{0,3}"),resiResiClass));
     resiResiClass->setMinimumWidth(100);
     connect(resiResiClass,SIGNAL(textEdited(const QString&)),this,SLOT(grossRC(const QString&)));
     resiResiClass->setEnabled(false);
@@ -42,16 +44,16 @@ DragDropAtomsDialog::DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<i
     rhla->addWidget(resiResiClassL);
     rhla->addWidget(resiResiClass);
     zoomIn = new QToolButton (this);
-    zoomIn-> setIcon(QIcon(":/xle-icons/zoom-in.png"));
-    zoomIn->setShortcut(QKeySequence(Qt::ALT +Qt::Key_PageUp));
+    zoomIn-> setIcon(QIcon(chgl->theIconPath+"zoom-in.svg"));
+    zoomIn->setShortcut(QKeySequence(Qt::ALT | Qt::Key_PageUp));
     zoomIn->setText("Zoom +");
     zoomIn->setToolTip("Zoom +");
     zoomIn->setAutoRepeat(true);
     zoomIn->setAutoRepeatDelay(150);
     zoomIn->setAutoRepeatInterval(3);
     zoomOut = new QToolButton(this);
-    zoomOut->setShortcut(QKeySequence(Qt::ALT +Qt::Key_PageDown));
-    zoomOut->setIcon(QIcon(":/xle-icons/zoom-out.png"));
+    zoomOut->setShortcut(QKeySequence(Qt::ALT | Qt::Key_PageDown));
+    zoomOut->setIcon(QIcon(chgl->theIconPath+"zoom-out.svg"));
     zoomOut->setText("Zoom -");
     zoomOut->setToolTip("Zoom -");
     zoomOut->setAutoRepeat(true);
@@ -60,9 +62,9 @@ DragDropAtomsDialog::DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<i
 
 
     rotLeft = new QToolButton(this);
-    rotLeft->setIcon(QIcon(":/xle-icons/moveleft.png"));
+    rotLeft->setIcon(QIcon(chgl->theIconPath+"moveleft.svg"));
     rotLeft->setText("rotate couter clock wise");
-    rotLeft->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Left));
+    rotLeft->setShortcut(QKeySequence(Qt::ALT | Qt::Key_Left));
     rotLeft->setToolTip("rotate couter clock wise");
     rotLeft->setAutoRepeat(true);
     rotLeft->setAutoRepeatDelay(50);
@@ -70,22 +72,22 @@ DragDropAtomsDialog::DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<i
 
 
     rotRight = new QToolButton(this);
-    rotRight->setIcon(QIcon(":/xle-icons/moveright.png"));
+    rotRight->setIcon(QIcon(chgl->theIconPath+"moveright.svg"));
     rotRight->setText("rotate clock wise");
     rotRight->setToolTip("rotate clock wise");
-    rotRight->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Right));
+    rotRight->setShortcut(QKeySequence(Qt::ALT | Qt::Key_Right));
     rotRight->setAutoRepeat(true);
     rotRight->setAutoRepeatDelay(50);
     rotRight->setAutoRepeatInterval(3);
 
     rotUp = new QToolButton(this);
-    rotUp->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Up));
+    rotUp->setShortcut(QKeySequence(Qt::ALT | Qt::Key_Up));
 
     rotUp->setAutoRepeatDelay(50);
     rotUp->setAutoRepeat(true);
     rotUp->setAutoRepeatInterval(3);
     rotDown = new QToolButton(this);
-    rotDown->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Down));
+    rotDown->setShortcut(QKeySequence(Qt::ALT | Qt::Key_Down));
     rotDown->setAutoRepeatDelay(50);
     rotDown->setAutoRepeat(true);
     rotDown->setAutoRepeatInterval(3);
@@ -104,7 +106,7 @@ DragDropAtomsDialog::DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<i
     mola->addWidget(rotRight,1,2);
     mola->addWidget(rotUp,0,1);
     mola->addWidget(rotDown,2,1);
-    QPixmap up = QPixmap(":/xle-icons/moveright.png");
+    QPixmap up = QPixmap(chgl->theIconPath+"moveright.svg");
     QTransform transform;
     QTransform t90 = transform.rotate(-90);
     QTransform t270 = transform.rotate(180);
@@ -132,9 +134,9 @@ void DragDropAtomsDialog::renameRNchanged(int ii){
   QMap<int,QString> resNrClass;
   for (int i=0; i<resiFinder->count(); i++){
     QString resil=resiFinder->itemText(i).toUpper();
-    resil.remove(QRegExp("^RESI"));
+    resil.remove(QRegularExpression("^RESI"));
     QString resinr=resil;
-    resil.remove(QRegExp("\\b\\d+\\b"));
+    resil.remove(QRegularExpression("\\b\\d+\\b"));
     resinr.remove(resil.trimmed());
     int rn=resinr.trimmed().toInt();
     resNrClass[rn]=resil.trimmed();
@@ -154,32 +156,32 @@ void DragDropAtomsDialog::renameRNchanged(int ii){
 
 void DragDropAtomsDialog::zoomin(){
   chgl->zoom(0.1);
-  chgl->updateGL();
+  chgl->update();
 }
 
 void DragDropAtomsDialog::zoomout(){
   chgl->zoom(-0.1);
-  chgl->updateGL();
+  chgl->update();
 }
 
 void DragDropAtomsDialog::rotr(){
   chgl->rotY(-0.05);
-  chgl->updateGL();
+  chgl->update();
 }
 
 void DragDropAtomsDialog::rotl(){
   chgl->rotY(0.05);
-  chgl->updateGL();
+  chgl->update();
 }
 
 void DragDropAtomsDialog::rotu(){
   chgl->rotX(0.05);
-  chgl->updateGL();
+  chgl->update();
 }
 
 void DragDropAtomsDialog::rotd(){
   chgl->rotX(-0.05);
-  chgl->updateGL();
+  chgl->update();
 }
 
 DragDropAtoms::DragDropAtoms(Molecule &mole, const QList<int> &reference, QList<int> *target, QWidget *parent)
@@ -307,7 +309,7 @@ void DragDropAtoms::dropEvent(QDropEvent *event){
         printf("%d %s %s\n",i,m_mole.asymm.at(k).Label.toStdString().c_str(),m_mole.asymm.at(j).Label.toStdString().c_str());
     }
   } /*else if (event->mimeData()->hasText()) {
-    QStringList pieces = event->mimeData()->text().split(QRegExp("\\s+"),
+    QStringList pieces = event->mimeData()->text().split(QRegularExpression("\\s+"),
 		    skipEmptyParts);
     QPoint position = event->pos();
 
@@ -373,7 +375,12 @@ void DragDropAtoms::mousePressEvent(QMouseEvent *event){
 
   QDrag *drag = new QDrag(this);
   drag->setMimeData(mimeData);
+#if (QT_VERSION >0x050f00)
+  Qt::ReturnByValueConstant rbvc=Qt::ReturnByValueConstant();
+  drag->setPixmap(child->pixmap(rbvc));
+#else
   drag->setPixmap(*child->pixmap());
+#endif
   drag->setHotSpot(hotSpot);
 
   child->hide();
