@@ -10,7 +10,6 @@
 
 #include "dsrglwindow.h"
 #include "molecule.h"
-//#include "chgl.h"
 #include "dsrgui.h"
 #include "glureplace.h"
 
@@ -21,49 +20,51 @@ DSRGlWindow::DSRGlWindow(QWidget *parent, Molecule *m,
   m_molecule=m;
   showFit=NULL;
   showFitLabel=NULL;
-  mole.cell.symmops.clear();
-  mole.cell.trans.clear();
-  mole.asymm.clear();
-  mole.sdm.clear();
-  mole.showbonds.clear();
-  mole.showatoms.clear();
-  mole.selectedatoms.clear();
-  mole.envi_sdm.clear();
-  mole.contact.clear();
-  mole.envi_sdm.clear();
-  mole.contact.clear();
-  mole.symmopsEQIV.clear();
-  mole.labelEQIV.clear();
-  mole.transEQIV.clear();
-  mole.freeatoms.clear();
-  mole.bindatoms.clear();
-  mole.selectedatoms.clear();
-  mole.showatoms.clear();
-  dsrLabelColor = QColor("white");
+  /*
+  m_molecule->cell.symmops.clear();
+  m_molecule->cell.trans.clear();
+  m_molecule->asymm.clear();
+  m_molecule->sdm.clear();
+  m_molecule->showbonds.clear();
+  m_molecule->showatoms.clear();
+  m_molecule->selectedatoms.clear();
+  m_molecule->envi_sdm.clear();
+  m_molecule->contact.clear();
+  m_molecule->envi_sdm.clear();
+  m_molecule->contact.clear();
+  m_molecule->symmopsEQIV.clear();
+  m_molecule->labelEQIV.clear();
+  m_molecule->transEQIV.clear();
+  m_molecule->freeatoms.clear();
+  m_molecule->bindatoms.clear();
+  m_molecule->selectedatoms.clear();
+  m_molecule->showatoms.clear();
   V3 nl(0,0,0);
-  mole.cell.trans.append(nl);
-  mole.cell.symmops.append(Matrix(1,0,0, 0,1,0, 0,0,1));
-  mole.pmin=10000;
-  mole.pmax=-10000;
-  mole.LOD=3;
-  labScal=0.4;
+  m_molecule->cell.trans.append(nl);
+  m_molecule->cell.symmops.append(Matrix(1,0,0, 0,1,0, 0,0,1));
+  m_molecule->pmin=10000;
+  m_molecule->pmax=-10000;
   // initial zoom level:
   // The Zom will later be adapted to fragment size.
+  m_molecule->transEQIV.clear();
+  m_molecule->symmopsEQIV.clear();
+  m_molecule->labelEQIV.clear();
+  m_molecule->freeatoms.clear();
+  m_molecule->bindatoms.clear();
+  m_molecule->envi_sdm.clear();
+  */
   L=50.0;
-  mole.transEQIV.clear();
-  mole.symmopsEQIV.clear();
-  mole.labelEQIV.clear();
-  mole.freeatoms.clear();
-  mole.bindatoms.clear();
-  mole.envi_sdm.clear();
+  m_molecule->LOD=3;
+  labScal=0.4;
+  dsrLabelColor = QColor("white");
   if (fragment.size() > 0) {
     display_fragment(header);
   }
 }
 
 DSRGlWindow::~DSRGlWindow() {
-    mole.g_Program->release();
-    mole.g_Program->deleteLater();
+    m_molecule->g_Program->release();
+    m_molecule->g_Program->deleteLater();
 }
 
 static inline void transform_point(GLdouble out[4], const GLdouble m[16], const GLdouble in[4]) {
@@ -82,7 +83,7 @@ static inline void transform_point(GLdouble out[4], const GLdouble m[16], const
 static inline bool  posTo2D(V3 obj,
 		const GLdouble model[16], const GLdouble proj[16],
 		const GLint viewport[4],
-        GLdouble * winx, GLdouble * winy,int retinafktr=1) {
+        GLdouble * winx, GLdouble * winy,double retina = 1.0) {
   GLdouble in[4], out[4];
 
   in[0] = obj.x;
@@ -100,8 +101,8 @@ static inline bool  posTo2D(V3 obj,
 
   *winx = viewport[0] + (1 + in[0]) * viewport[2] / 2;
   *winy = viewport[1] + (1 - in[1]) * viewport[3] / 2;  
-  *winx /= retinafktr;
-  *winy /= retinafktr;
+  *winx /= retina;
+  *winy /= retina;
   return true;
 }
 
@@ -141,7 +142,7 @@ void DSRGlWindow::renderText(double x, double y, double z, const QString &text){
 
 
 void DSRGlWindow::draw(){
-  mole.dratom = 0;
+  m_molecule->dratom = 0;
   glPushMatrix();
   glScaled( L, L, L );
   GLdouble model[16];
@@ -172,14 +173,14 @@ void DSRGlWindow::draw(){
     proj[1]*proj[6]*proj[8]  - proj[9]*proj[6]*proj[0]+
     proj[2]*proj[4]*proj[9]  - proj[10]*proj[4]*proj[1];
   printf("die Determinante der Drehmatrix ist: %g\n",det);*/
-  mole.adp = 0;
-  mole.intern = 0;
-  mole.tubes = 0;
+  m_molecule->adp = 0;
+  m_molecule->intern = 0;
+  m_molecule->tubes = 0;
   glDisable(GL_BLEND);  
   glEnable(GL_DEPTH_TEST );
   glDepthFunc(GL_LEQUAL);
-  mole.atoms(xd, 50, 0.5);//smaller atoms
-  mole.bonds(bonds,0.5);
+  m_molecule->atoms(xd, 50, 0.5);//smaller atoms
+  m_molecule->bonds(bonds,0.5);
   glEnable(GL_COLOR_MATERIAL);
   qglColor(dsrLabelColor);  // The fragment label color
 //  glClear( GL_DEPTH_BUFFER_BIT);
@@ -190,7 +191,7 @@ void DSRGlWindow::draw(){
       in[2] = xd.at(i).pos.z;
       in[3] = 1.0;
       transform_point(out, model, in);
-      posTo2D(xd.at(i).pos,model,proj,viewport, &xd[i].screenX, &xd[i].screenY);
+      posTo2D(xd.at(i).pos,model,proj,viewport, &xd[i].screenX, &xd[i].screenY,1.0);
       bool issel=false;
       for (int j=0; j<selFragAt.size(); j++) {
         if ((showFitLabel!=nullptr)
@@ -210,25 +211,25 @@ void DSRGlWindow::draw(){
 
 
 
-  for (int i=0; i<xd.size(); i++){
+ /* for (int i=0; i<xd.size(); i++){
       GLdouble in[4], out[4];
       in[0] = xd.at(i).pos.x;
       in[1] = xd.at(i).pos.y;
       in[2] = xd.at(i).pos.z;
       in[3] = 1.0;
       transform_point(out, model, in);
-      posTo2D(xd.at(i).pos,model,proj,viewport, &xd[i].screenX, &xd[i].screenY);
-  }
+      posTo2D(xd.at(i).pos,model,proj,viewport, &xd[i].screenX, &xd[i].screenY, retinafktr);
+  }*/
   glPopMatrix();
   if (!selFragAt.isEmpty()){
     glPushMatrix();{
       glScaled( L, L, L );
-      mole.tubes=0;
-      mole.intern=1;
-      mole.adp=0;
-      mole.dratom=1;
-      mole.atoms(selFragAt);
-      mole.dratom=0;
+      m_molecule->tubes=0;
+      m_molecule->intern=1;
+      m_molecule->adp=0;
+      m_molecule->dratom=1;
+      m_molecule->atoms(selFragAt);
+      m_molecule->dratom=0;
       glPolygonMode(GL_FRONT_AND_BACK,GL_FILL);
     }glPopMatrix();
   }
@@ -236,13 +237,13 @@ void DSRGlWindow::draw(){
     glPushMatrix();{
       glEnable(GL_BLEND);
       glScaled( L, L, L );
-      mole.tubes=0;
-      mole.intern=0;
-      mole.adp=0;
-      mole.dratom=5;
-      mole.atoms(fita);
-      mole.dbond(fitabonds);
-      mole.lbond();
+      m_molecule->tubes=0;
+      m_molecule->intern=0;
+      m_molecule->adp=0;
+      m_molecule->dratom=5;
+      m_molecule->atoms(fita);
+      m_molecule->dbond(fitabonds);
+      m_molecule->lbond();
       if (showFitLabel->isChecked()){
         qglColor(QColor(0, 0, 175));  // The surrounding atoms label color
         for (int i=0; i<fita.size(); i++){
@@ -294,25 +295,26 @@ void DSRGlWindow::initializeGL(){
   glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
 
   makeCurrent();
-  mole.g_Program=new QOpenGLShaderProgram(this);
-  mole.g_program=mole.installShader();
+  m_molecule->g_Program=new QOpenGLShaderProgram(this);
+  m_molecule->g_program=m_molecule->installShader();
   GLenum err = GL_NO_ERROR;
   int ect=0;
-  printf("DSR shaderprog %d context is valid = %d \n",mole.g_program,context()->isValid());
-  if (!mole.g_program) printf("%s\n",mole.g_Program->log().toStdString().c_str());
+  printf("DSR shaderprog %d context is valid = %d \n",m_molecule->g_program,context()->isValid());
+  if (!m_molecule->g_program) printf("%s\n",m_molecule->g_Program->log().toStdString().c_str());
   while((err = glGetError()) != GL_NO_ERROR){
     printf("in DSR: GL_INVALID_VALUE%d GL_INVALID_OPERATION%d [%d] err=%x\n",err==GL_INVALID_VALUE ,err == GL_INVALID_OPERATION,++ect,err);
   }
 }
 
 void DSRGlWindow::resizeGL(int width, int height){
-#if defined Q_OS_MAC && (QT_VERSION >= 0x050000)
-    retinafktr = 2;
-#else
-    retinafktr = 1;
-#endif
-  glViewport(0, 0, width*retinafktr, height*retinafktr);
+    retinafktr=devicePixelRatio();// it qt5 this is in in qt6 its qreal!!
+    printf("retinafktr=%f\n",retinafktr);
+    wh=height*retinafktr;
+    ww=width*retinafktr;
+  glViewport(0, 0, ww, wh);
   glGetIntegerv(GL_VIEWPORT, vp);
+  printf("VP %d %d %d %d  w = %d h = %d  width = %d height = %d retina factor = %f devicePixelRatio() = %f\n",vp[0],vp[1],vp[2],vp[3],ww,wh,
+         this->width(),this->height(),retinafktr,devicePixelRatio());
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluPerspective_( 29.0, (double)width/height, 5.0, 8000.0 );
@@ -331,15 +333,11 @@ QSize DSRGlWindow::sizeHint() const
 void DSRGlWindow::paintGL(){
   glClearColor(0.6f,0.6f,0.6f,1.0f); // The background color
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-#if defined Q_OS_MAC && (QT_VERSION >= 0x050000)
-  glViewport(0, 0, QOpenGLWidget::width()*2, QOpenGLWidget::height()*2);
-#else  
-  glViewport(0, 0, QOpenGLWidget::width(), QOpenGLWidget::height());
-#endif
+  glViewport(0, 0, ww, wh);
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
-  gluPerspective_( 29.0, (double)QOpenGLWidget::width()/QOpenGLWidget::height(), 5.0, 8000.0 );
+  gluPerspective_( 29.0, (double)ww/wh, 5.0, 8000.0 );
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
   draw();
@@ -396,8 +394,8 @@ void DSRGlWindow::display_fragment(DSRMol frag, bool clear_sel)
   for (int i=0; i<xd.size(); i++){
     xd[i].pos += mid;
   }
-  L = 90.0/mole.dimension(xd); // Zoom level of the molecule inside the widget
-  bonds=mole.connecting(xd,true);
+  L = 90.0/m_molecule->dimension(xd); // Zoom level of the molecule inside the widget
+  bonds=m_molecule->connecting(xd,true);
   update();
 }
 
@@ -638,7 +636,7 @@ void DSRGlWindow::tryfit(){
       fita.removeLast();
     }
   }  
-  fitabonds=mole.connecting(fita,true);
+  fitabonds=m_molecule->connecting(fita,true);
   update();
 //  printf("FIT:\n================================================================================\n");
   for (int i=0; i<xd.size(); i++){
