@@ -43,14 +43,15 @@ private:
   void glTranslateL( const double dx, const double dy, const double dz );
   void glRotateL( const double dang, const double x, const double y, const double z );
   QFont myFont; //!< a font for the atom labels
-  Molecule mole;
+  //Molecule mole;
   QColor dsrLabelColor;
   GLint vp[4];  
   double labScal;
   void draw();
-  int retinafktr = 1;
+  double retinafktr = 1;
   void project(double x, double y, double z, GLdouble &tx, GLdouble &ty);
   double L, moux, mouy;
+  int wh,ww;
   void tryfit();
   virtual QSize sizeHint() const override;
   virtual QSize minimumSizeHint() const override;
