@@ -51,11 +51,6 @@ Explanations
 */
 
 
-/*
- * TODO:
-*/
-
-
 DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(parent) {
   m_shelxle = parent;
   m_molecule = mole;
@@ -156,7 +151,6 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   fragmentNameTag.clear();
   // The OpenGL widget with the molecule:
   mygl = new DSRGlWindow(this, m_molecule, *header, fragmentNameTag);
-  m_molecule->loadSettings();
   mygl->showFit = new QCheckBox(tr("show fitted target overlay"));
   mygl->showFit->setChecked(true);
   mygl->showFitLabel = new QCheckBox(tr("labels on target overlay"));
