@@ -18,10 +18,10 @@
 #include <QDialog>
 #include <QModelIndex>
 #include <QNetworkAccessManager>
-#include <QNetworkSession>
-#include <QTcpServer>
-#include <QTcpSocket>
-#include <QUdpSocket>
+//#include <QNetworkSession>
+//#include <QTcpServer>
+//#include <QTcpSocket>
+//#include <QUdpSocket>
 
 class Window;
 class Molecule;
@@ -67,19 +67,17 @@ private:
   QLineEdit *occEdit;              //!< Input field for the SHELXL occupancy
   //QLineEdit *resinumEdit;          //!< Input field for residue numbers (obsolete, because is automatically determined)
   QLineEdit *resiclassEdit;        //!< Input field for the residue class
-  QVBoxLayout *mainVLayout;
+  QGridLayout *mainLayout;
   QHBoxLayout *editLayout;
-  QVBoxLayout *optionsLayout1;     //!< Layout for the PARt FVAR OCC replace options
+  QGridLayout *optionsLayout1;     //!< Layout for the PARt FVAR OCC replace options
   QVBoxLayout *optionsLayout2;     //!< Layout for invert external and rigid group options
   QVBoxLayout *optionsLayout3;     //!< Layout for the residue and user manual options
   QVBoxLayout *buttonLayout;       //!< Layout for fit, export and edit buttons
   QHBoxLayout *searchLayout;
-  QHBoxLayout *partLayout;
-  QHBoxLayout *fvarLayout;
-  QHBoxLayout *occLayout;
   QHBoxLayout *resclassLayout;
-  QGridLayout *chooserLayout;
   QHBoxLayout *optionboxes;
+  QGridLayout *glo;
+  QGridLayout *flo;
   QSpinBox    *partspinner; //!< part definition spinbox
   QSpinBox    *fvarspinner; //!< part definition spinbox
   QPushButton *editButton;  //! Button to start the fragment editor
@@ -138,7 +136,7 @@ private:
   void getVersionFromServer();
   bool runTCPServer();
   QLabel *statusLabel;
-  QTcpServer *tcpServer;
+  //QTcpServer *tcpServer;
 signals:
   void optionTextChanged(void);
   void fragmentSelected(void);
@@ -187,7 +185,7 @@ public slots:
   void splitSelectedAtoms();
   bool runDSR(QString option, bool showresults=true, QString workdir="");
   bool open_last_fileversion();
-  void ReadClientData();
+  //void ReadClientData();
 protected:
   virtual void closeEvent(QCloseEvent * event);
 
