@@ -29,6 +29,8 @@
 #include <QScrollArea>
 #include "molecule.h"
 #include "psewidget.h"
+#include "opengltestwidget.h"
+
 /*! \brief EacGLW is the QGLWidget of the Edit Atom Styles Dialog EacDlg. 
  * 
  * EacGLW displays a sp3 like molecule. The 'molecule' consists of a central atom with anisotrop ADP and a neighboring atom without ADP 
@@ -36,7 +38,7 @@
  * rotates continously around its own axis which itself rotates as well. This widget demonstates the look and feel of an atom specific 
  * setting which can be changed in the EacDlg. 3 Q-Peaks are displayed arround the molecule. 
  */
-
+/*
 class EacGLW: public QOpenGLWidget {
 Q_OBJECT
   public:
@@ -54,7 +56,6 @@ Q_OBJECT
   //QStringList pse;
   PSEWidget *psew;  
   QSettings *einstellung;
-  QTimer *timer;//!< a timer for the molecule rotation
   void qglColor(const QColor c);
   void renderText(double x, double y, double z, const QString &str);
   void setMSAA(bool);
@@ -70,8 +71,6 @@ Q_OBJECT
         default : return QString("Some other OpenGL error."); break;
         }
     }
-  signals:
-      void colorchanged(QColor bgcolor);//!< colorchanged is emitted  by the color dialog colorDLG to change the color of a chemical element. @param bgcolor the new color
  protected:
   void initializeGL();
   void resizeGL(int width, int height);
@@ -89,14 +88,17 @@ Q_OBJECT
  private:
   GLint vp[4];
   void draw();
-  int retinafktr = 1;
+  double retinafktr = 1;
   void project(double x, double y, double z, GLdouble &tx, GLdouble &ty);
   static inline void transform_point(GLdouble out[4], const GLdouble m[16], const GLdouble in[4]); 
   static inline bool posTo2D(V3 obj, const GLdouble model[16], const GLdouble proj[16],
-    const GLint viewport[4], GLdouble &winx, GLdouble &winy,int retinafktr); 
+    const GLint viewport[4], GLdouble &winx, GLdouble &winy,double retinafktr);
   QColor backGroundColor;
   QColor labelColor;
 };
+*/
+
+
 /*! \brief MultiStyle a small dialog called in EacDlg to change the style of multiple elements at once.
  */
 class MultiStyle: public QDialog {
@@ -116,6 +118,7 @@ Q_OBJECT
   void checkWall();
   void checkSolid();
   void checkBall();
+  void commonDefault();
  private:
   Molecule *mol;
 };
@@ -125,16 +128,49 @@ class EacDlg: public QDialog {
 Q_OBJECT
   public:
   explicit EacDlg(Molecule *externMole);
+    PlayOpenGL *ogl;
+    void storeColors(){
+        einstellung->beginGroup("Colors");
+        einstellung->setValue("LabelColor",ogl->labelColor);
+        einstellung->setValue("LabelBGColor",ogl->labelBGColor);
+        einstellung->setValue("focusedLabelBGColor", ogl->focusedLabelBGColor);;
+        einstellung->setValue("focusedLabelColor", ogl->focusedLabelColor);
+        einstellung->setValue("selectedLabelBGColor", ogl->selectedLabelBGColor);;
+        einstellung->setValue("selectedLabelColor", ogl->selectedLabelColor);
+        einstellung->setValue("BackGroundColor",ogl->backGroundColor);
+        einstellung->endGroup();
+        update();
+        ogl->makeLabels();
+        ogl->update();
+    }
+    bool areLabelsShort(){return ogl->shortLabels->isChecked();}
   //EacDlg(MyAtom *onlyThisAtom,Molecule *externMole);
+signals:
+    void colorchanged(QColor bgcolor);//!< colorchanged is emitted  by the color dialog colorDLG to change the color of a chemical element. @param bgcolor the new color
+    void statesChanged();
   public slots:
   void colorDLG2();//!< opens the bond color dialog.
+  void colorDLGLabel();
+  void colorDLGFLabel();
+  void colorDLGSLabel();
+  void bgColorDLGLabel();
+  void bgColorDLGFLabel();
+  void bgColorDLGSLabel();
+  void labelColorAlpha(int a);
+  void slabelColorAlpha(int a);
+  void flabelColorAlpha(int a);
+  void labelBGColorAlpha(int a);
+  void slabelBGColorAlpha(int a);
+  void flabelBGColorAlpha(int a);
+  void changeLabelFont();
+
   void colorDLGenvibon();
   void colorDLGenvidef();
   void colorDLGenvihbo();
   void colorchange(QColor bgcolor);//!< changes the color of the current element to bgcolor. Changes the color of the corresponding button.
-  void updateLEs(int OZ, bool HisD);//!< when the current element changes the settings of this element are loaded and applied to the EacGLW widget and the PSEWidget. @param OZ atomic number (staring from zero) of the new atom
+  void updateLEs(int OZ = 5, bool HisD = false);//!< when the current element changes the settings of this element are loaded and applied to the EacGLW widget and the PSEWidget. @param OZ atomic number (staring from zero) of the new atom
   void checkWall();//!< when solid is checked then solid is unchecked.
-  void checkShader(bool b);
+  //void checkShader(bool b);
   void checkSolid();//!< when walls are checked solid is unchecked. 
   void checkBall();//!< when ellipsoid surface is unchecked the solid checkbox is diabled. 
   void doMulti();//!< calls MultiStyle dialog
@@ -152,12 +188,42 @@ Q_OBJECT
   void hbdistChanged(double);//!< maximal length for H-bonds
   void hbanglChanged(double);//!< maximal angle for H-bonds
   void updateHBElemnts();//!< H-bond accepor or donor list has changed
+  void makedemomol();
+  void updateShaders();
+  void toggleRotation(bool b){
+      if ((b)&&(!timer->isActive())) timer->start(20);
+      else timer->stop();
+      ogl->update();
+  }
+
+
+  void changeAtom(int OZ, bool HisD);//!< changes the atom type of the central atom in OZ @param OZ atomic number (staring from zero) of the new atom
+  void colorDLG();//!< changes the color of an atom type
+  void wallA(int st);//!< wallA changes the state of the ellipsoid wall. @param st is the checkbox state of the calling QCheckBox.
+  void ringA(int st);//!< ringA changes the state of the principal ellipses. @param st is the checkbox state of the calling QCheckBox.
+  void spheA(int st);//!< spheA changes the state of the ellipsoid surface. @param st is the checkbox state of the calling QCheckBox.
+  void soldA(int st);//!< soldA changes the transparence state of the ellipsoid surface. @param st is the checkbox state of the calling QCheckBox.
+  void nolaA(int st);//!< nolaA changes the state of the atom labels @param st is the checkbox state of the calling QCheckBox.
+  void whitA(int st);//!< whitA changes the color of the principal ellipses from black to white. @param st is the checkbox state of the calling QCheckBox.
+  void metalA(int st);//!< metalA changes the state of the bond to without this feature checked on into stipled style @param st is the checkbox state of the calling QCheckBox.
+
   protected slots:
   void accept () ;
   void reject () ;
  private:
-  EacGLW *eacGLW;//!<The QGLWidget displaying an example molecule.
+  //EacGLW *eacGLW;//!<The QGLWidget displaying an example molecule.
+  void createOGL();  
+  QTimer *timer=nullptr;//!< a timer for the molecule rotation
+  bool pause4LE = false;
+  QString theIconPath;
+  QToolBar *vito;
+  QPeakView *qpv;
   Molecule *mol;
+  CEnvironment demo;
+  CEnvironment exmol;
+  Connection demobonds;
+  Connection exbond;
+  QSettings *einstellung;
   //MyAtom *otm;
   QCheckBox *shaderUse;
   QDoubleSpinBox *bondStrength;
@@ -179,7 +245,15 @@ Q_OBJECT
   QCheckBox *sldbx;
   QCheckBox *nlabx;
   QCheckBox *metalic;
+  QCheckBox *idlerot;
+  QPushButton *colorbutlab;
+  QPushButton *bgcolorbutlab;
+  QPushButton *colorbutflab;
+  QPushButton *bgcolorbutflab;
+  QPushButton *colorbutslab;
+  QPushButton *bgcolorbutslab;
 
   QCheckBox *noadp;
+  QComboBox* demoMoleculeBox;
 };
 #endif
