@@ -4,6 +4,14 @@
 #include <QObject>
 #include <QWidget>
 #include <QtGui>
+#include <QDialog>
+#include <QGridLayout>
+#include <QLineEdit>
+#include <QPlainTextEdit>
+#include <QComboBox>
+#include <QSpinBox>
+#include <QCheckBox>
+#include <QDialogButtonBox>
 #include "molecule.h"
 
 #if defined Q_WS_WIN || defined Q_OS_WIN
