@@ -430,7 +430,14 @@ void FcVsFo::omitref(){
 
 void FcVsFo::selektiert(){
   
-  QString s="<h1>Selected Reflections</h1> <table><tr><th width=\"30\">h</th><th width=\"30\">k</th><th width=\"30\">l</th><th width=\"50\">Fo<sup>2</sup></th><th width=\"50\">Fc<sup>2</sup></th><th width=\"50\">&Delta;(F<sup>2</sup>)/sigma</th><th width=\"50\">sigma</th><th width=\"50\">sin(theta)/lambda</th></tr>\n";
+  QString s="<h1>Selected Reflections</h1> <table>"
+            "<tr><th width=\"30\">h</th>"
+            "<th width=\"30\">k</th>"
+            "<th width=\"30\">l</th>"
+            "<th width=\"70\">Fo<sup>2</sup></th>"
+            "<th width=\"55\">Fc<sup>2</sup></th>"
+            "<th width=\"50\">&Delta;(F<sup>2</sup>)/sigma</th>"
+            "<th width=\"50\">sigma</th><th width=\"50\">sin(theta)/lambda</th></tr>\n";
 //double wghta=0,wghtb=0;
   for (int i=0; i<scene->selected.size(); i++){
    int sel=scene->selected.at(i); 
