@@ -111,7 +111,9 @@ void Highlighter::highlightDupl(const CEnvironment &dupls){
   rehighlight();
 }
 
-void Highlighter::highlightBlock(const QString &text) {
+void Highlighter::highlightBlock(const QString &text) {    
+    //QElapsedTimer stech;
+    //stech.start();
   foreach (HighlightingRule rule, highlightingRules) {
     if (rule.Comment) continue;
     QRegularExpressionMatchIterator matchIterator = rule.pattern.globalMatch(text);
@@ -181,9 +183,12 @@ void Highlighter::highlightBlock(const QString &text) {
     }
   }
 //  printf("hi blo\n");
+  //fprintf(stderr,"hiliblo %dms\n",stech.elapsed());
 }
 
 void Highlighter::loadHighlightPatterns(QString FileName){
+    QElapsedTimer stech;
+    stech.start();
   //int group=1;  
   highlightingRules.clear();
   outputstyle=true;
@@ -203,13 +208,14 @@ void Highlighter::loadHighlightPatterns(QString FileName){
     pat->endGroup();
     group++;
     }*/
-  HighlightingRule rule;
+  static HighlightingRule rule;
   QStringList groups = pat->childGroups();
-  QRegularExpression Dplus = QRegularExpression("\\D+");
+  static QRegularExpression Dplus = QRegularExpression("\\D+");
   foreach (QString grp,groups){
     if (!grp.contains(Dplus)){
       pat->beginGroup(grp);
       rule.pattern.setPattern(pat->value("Pattern","").toString());
+      rule.pattern.setPatternOptions( QRegularExpression::CaseInsensitiveOption);
       rule.format.setForeground(QColor(pat->value("Color"           ,"#000000").toString()));
       rule.format.setBackground(QColor(pat->value("Background"      ,"#ffffff").toString()));
       rule.format.setFontWeight(pat->value("Weight"          ,50).toInt());
@@ -231,5 +237,5 @@ void Highlighter::loadHighlightPatterns(QString FileName){
       outputstyle=false;
     }
   }
-  //fprintf(stderr,"finished loadHighlightPatterns %s outputstyle=%s\n",FileName.toStdString().c_str(),(outputstyle)?"true":"false");
+  fprintf(stderr,"finished loadHighlightPatterns %s outputstyle=%s  %dms\n",FileName.toStdString().c_str(),(outputstyle)?"true":"false",stech.elapsed());
 }
