@@ -46,8 +46,7 @@
 #include "molecule.h"
 class QTextDocument;
 //! Highlighter changes the text style of the shelXle editor, output viewer and the list viewer \inherit QSyntaxHighlighter.
-class Highlighter : public QSyntaxHighlighter
-{
+class Highlighter : public QSyntaxHighlighter{
   Q_OBJECT
     
     public:
@@ -66,16 +65,15 @@ public slots:
   
  private:
   bool outputstyle;  
-  struct HighlightingRule
-  {
+  struct HighlightingRule {
     QRegularExpression pattern;
     QTextCharFormat format;
     bool Comment;
     inline bool operator == (const HighlightingRule &a){
-    return (pattern.pattern()==a.pattern.pattern());
-  }
+        return (pattern.pattern()==a.pattern.pattern());
+    }
   };
-  QList<HighlightingRule> highlightingRules,findRule;
+  QList<HighlightingRule> highlightingRules, findRule;
   QRegularExpression commentStartExpression;
   QRegularExpression commentEndExpression;
 
