@@ -2,13 +2,14 @@
 #define IDEAL_DEFDEN_H
 #include <QThread>
 #include "molecule.h"
-#include "chgl.h"
+//#include "chgl.h"
+#include "opengltestwidget.h"
 #include "fourxle.h"
 
 class IdealDefdenGenerator : public QThread{
 Q_OBJECT
   public:
-  IdealDefdenGenerator(ChGL *chgl_,FourXle *FX, QObject * parent = nullptr ){
+  IdealDefdenGenerator(PlayOpenGL *chgl_,FourXle *FX, QObject * parent = nullptr ){
     chgl = chgl_;
     mommy = parent;// maybe I need it later?
     fxle=FX;
@@ -19,7 +20,7 @@ Q_OBJECT
   }
   double defden(V3 pos,CEnvironment &belo, QList<Matrix> &mi);
   void beloWriteCube();//bello braf!
-  ChGL *chgl;
+  PlayOpenGL *chgl;
   QObject *mommy;//parent
   FourXle *fxle;
 
