@@ -1,8 +1,11 @@
 #include "includeeditor.h"
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QMessageBox>
 
 IncludeEditor::IncludeEditor(QString inclstr, const QString &_dir, QWidget *parent) : QDialog(parent){
     setWindowTitle(QString("included file :%1").arg(inclstr));
-    fileName = inclstr.remove(QRegExp("^\\++"));
+    fileName = inclstr.remove(QRegularExpression("^\\++"));
 
     dirName=_dir;
     fileName=QString("%1/%2").arg(dirName).arg(fileName);
