@@ -191,16 +191,13 @@ int main(int argv, char *args[]){
 #if (QT_VERSION >= 0x050000)
   QCoreApplication::setAttribute(Qt::AA_UseDesktopOpenGL);
   //printf("AA_UseDesktopOpenGL %d \n",QCoreApplication::testAttribute(Qt::AA_UseDesktopOpenGL));
+  printf("Qt::AA_ShareOpenGLContexts %d\n",QCoreApplication::testAttribute(Qt::AA_ShareOpenGLContexts));
   QApplication app(argv, args);
-  /*QSurfaceFormat f = QSurfaceFormat::defaultFormat();
+  QSurfaceFormat f = QSurfaceFormat::defaultFormat();
   //printf("??\n");
-  f.setSampleBuffers(true);
-  QOpenGLFormat::setDefaultFormat(f);
-  if (!QOpenGLFormat::hasOpenGL()) {
-  QMessageBox::information(0, "OpenGL samplebuffers",
-               "This system does not support OpenGL.");
-      return 0;
-  }*/
+  //f.setSampleBuffers(true);
+  f.setSwapInterval(0);
+  QSurfaceFormat::setDefaultFormat(f);
 #else
     QApplication app(argv, args);
 #endif
@@ -214,9 +211,11 @@ int main(int argv, char *args[]){
   qInstallMsgHandler(mh);
 #endif 
   //printf("??1\n");
-  ChGL *chgl = new ChGL(0);
+  //ChGL *chgl = new ChGL(0);
+  //PlayOpenGL *chgl = new PlayOpenGL();
   //printf("??2 %p\n",chgl);
-  Window *window = new Window(chgl);
+  Window *window = new Window();
+  //printf("??2.5 %p\n",window->chgl);
   window->chgl->setMainWindow(window);
   //printf("??3\n");
   window->show();
