@@ -174,7 +174,30 @@ struct Matrix{
     m11(x11), m21(x21), m31(x31),
     m12(x12), m22(x22), m32(x32),
     m13(x13), m23(x23), m33(x33){;}
+  inline Matrix( const QMatrix4x4 &m44):
+      m11(m44(0,0)), m21(m44(0,1)), m31(m44(0,2)),
+      m12(m44(1,0)), m22(m44(1,1)), m32(m44(1,2)),
+      m13(m44(2,0)), m23(m44(2,1)), m33(m44(2,2))
+  {;}
+  inline Matrix( const QMatrix3x3 &m33):
+      m11(m33(0,0)), m21(m33(0,1)), m31(m33(0,2)),
+      m12(m33(1,0)), m22(m33(1,1)), m32(m33(1,2)),
+      m13(m33(2,0)), m23(m33(2,1)), m33(m33(2,2))
+  {;}
+  inline Matrix operator *= (const double a){
+    m11 *= a;
+    m21 *= a;
+    m31 *= a;
 
+    m12 *= a;
+    m22 *= a;
+    m32 *= a;
+
+    m13 *= a;
+    m23 *= a;
+    m33 *= a;
+    return *this;
+  }
 };
 inline Matrix transponse (Matrix a){//transponse
   return Matrix(
@@ -250,6 +273,7 @@ inline Matrix operator * (const Matrix &a,const double &b){
   erg.m33 = a.m33*b;
   return erg;
 }
+
 inline Matrix operator + (const Matrix &a, const Matrix &b){
   Matrix erg;
   erg.m11 = a.m11+b.m11;
@@ -334,6 +358,33 @@ typedef struct MyAtom{
   GLdouble screenX;
   //! the screen position Y 
   GLdouble screenY;
+  QString toAtomString() const{
+      return QString("%1!%2!%3!%4!%5!%6!%7!%8!%9!%10!%11!%12!%13!%14!%15!%16!%17!%18!%19!%20!%21!%22!%23!%24!%25!%26!%27!%28!%29!%30!%31!%32!%33!%34!%35!%36!%37!%38!%39!%40!%41!%42!%43!%44!%45\n")
+              .arg(Label,ResiClass,orginalLine)//1
+              .arg(molindex)
+              .arg(fixFlag)
+              .arg(symmGroup)
+              .arg(sg)
+              .arg(scod)
+              .arg(auidx)
+              .arg(hidden)
+              .arg(sof_org)
+              .arg(sof)
+              .arg(isIso)
+              .arg(ufiso_org)
+              .arg(uf.m11).arg(uf.m12).arg(uf.m13).arg(uf.m21).arg(uf.m22).arg(uf.m23).arg(uf.m31).arg(uf.m32).arg(uf.m33)
+              .arg(uc.m11).arg(uc.m12).arg(uc.m13).arg(uc.m21).arg(uc.m22).arg(uc.m23).arg(uc.m31).arg(uc.m32).arg(uc.m33)
+              .arg(pos.x).arg(pos.y).arg(pos.z)
+              .arg(frac.x).arg(frac.y).arg(frac.z)
+              .arg(peakHeight)
+              .arg(resiNr)
+              .arg(an)
+              .arg(part)
+              .arg(style)
+              .arg(afixParent)
+              .arg(afix)
+              ;
+  }
 }MyAtom;
 inline bool  operator == (const MyAtom &a1,const MyAtom &a2){
   return ((a1.Label == a2.Label)&&(a1.resiNr == a2.resiNr)&&(a1.part == a2.part)&&(a1.symmGroup == a2.symmGroup));
@@ -344,6 +395,7 @@ inline bool operator < (const MyAtom &a1, const MyAtom &a2){
 inline bool operator < (MyAtom &a1, MyAtom &a2){
   return (a1.Label < a2.Label);
 } 
+
 //! MyBond a bond object
 typedef struct MyBond{
   //! a pointer to the atom where the bond starts
@@ -371,7 +423,7 @@ struct Vert {
 };
 
 typedef struct VPoly{
- V3 mid,nor,verts0,verts1;
+ V3 mid,nor,verts0,verts1,color;
  int acol,intra;
 }VPoly;
 
@@ -442,6 +494,7 @@ struct Cell {
   //! the wavelenth  \f$ \lambda  \f$ in Angstroms
   double wave;
   Matrix G,Gi;//metric tensor and its inverse
+  QMatrix3x3 Cholesky;
 };
 //! shortest distance matrix item type
 struct SdmItem{
@@ -518,6 +571,7 @@ public:
     V3 applySymCode(const V3 &frac, int scode);//!< applies a platon style symmetry code as an integer (s555)
     double hbdist();
     double hbangl();
+    QMatrix3x3 cholesky();
     int installShader();
     void Farbverlauf (GLfloat wrt,GLfloat min,GLfloat max);//!<computes a gradient color for wrt which is between min and max and calls glColor. @param wrt value for which a color should be assigned. @param min minimum value of wrt.  @param max maximum value of wrt.
     Cell cell;//!<The unit cell parameters
@@ -548,6 +602,9 @@ public:
     bool   beloColorByDefden; 
     bool   beloLabels;
     Matrix rotarb(double *arr);
+    Matrix rotarb(double angle, V3 &arr);
+    void rotarb(Matrix &mat, double angle, V3 &arr);
+
     //GLuint hbtex; //!< texture handle for hydrogen bonds
     QOpenGLTexture *hbtex = nullptr;
     //	 hbtex2; //!< texture handle for
@@ -582,7 +639,8 @@ public:
     CEnvironment duplicateAtoms;//!< atom list of identcal labeled atoms.
     CEnvironment legendAtoms;//!< Atoms in a key legend.
     Connection showbonds;//!< list of visible bonds.
-    Connection splitbonds;
+    Connection splitLbonds;
+    Connection splitRbonds;
     Connection lbonds;//!< list of line bonds (for Q-Peaks)
     CEnvironment fitatoms;//!<
     Connection fitbonds;//!<
@@ -593,6 +651,7 @@ public:
     QString ffmpegexe;
     int vorobas;
     QString voroMsg;
+    MyAtom fromAtomString(const QString &s);
     V3 findGlide(V3 normal, V3 test, int n);
     V3 findGlide(V3 normal, V3 test, Matrix mat, V3 trans);
     QList<VPoly> vtriangles;
@@ -637,7 +696,8 @@ public:
     void lbond();
     void billBoard();
     QString h_bonds(Connection bond,CEnvironment atoms);
-    void h_bonds2(Connection bond,CEnvironment atoms);
+    void h_bonds2(Connection bond,CEnvironment atoms);    
+    void h_bonds3(Connection bond,CEnvironment atoms);
     void unitCell();
     Connection connecting(const CEnvironment &atom, bool eac=false);
     bool decodeSymmCard(const QString symmCard);
