@@ -29,6 +29,8 @@ PSEWidget::PSEWidget(Molecule *_mole, QWidget *parent) :
 //#define PROGRAM_NAME "shelXle"
     einstellung = new QSettings( QSettings::IniFormat, QSettings::UserScope ,PROGRAM_NAME,mole->mynewnameis ,this);
     sz=mole->pseFontSize;
+    QFont f=QFont();
+    if (mole->mynewnameis=="BrukerShelXle") sz=f.pointSize();
     QToolButton *TB;
     lplus = new QToolButton();
     lplus->setIcon(QIcon(mole->theIconPath+"efplus.svg"));
@@ -93,7 +95,11 @@ PSEWidget::PSEWidget(Molecule *_mole, QWidget *parent) :
 #endif
     connect(lminus,SIGNAL(pressed()),this,SLOT(decFontSize()));
 
-
+  if (mole->mynewnameis=="BrukerShelXle"){
+      printf("I am %s\n",mole->mynewnameis.toStdString().c_str());
+      lminus->hide();
+      lplus->hide();
+  }
 /*    a=viewMenu->addAction(QIcon(mole->theIconPath+"laminus.svg"),
 		    tr("decrease label fontsize"),chgl,SLOT(decFontSize()),
 		    QKeySequence("Alt+-"));*/
