@@ -23,6 +23,7 @@
 #include <QSignalMapper>
 #include <QDebug>
 #include <QToolButton>
+#include <QApplication>
 #include "molecule.h"
 #include "itsme.h"
 /*! \brief PSEWidget is a widget that features a periodic table of the elements. 
@@ -35,19 +36,27 @@ class PSEWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit PSEWidget(QWidget *parent = 0);
+    explicit PSEWidget(Molecule *_mol, QWidget *parent = 0);
     int selection;//!< The curent selected element starting from zero which refers to Hydrogen 
     QSignalMapper* esm;
+    bool HisD;
 signals:
-void pseSelected(int index);//!< This signal is emitted when an element is clicked.
+void pseSelected(int index, bool HisD);//!< This signal is emitted when an element is clicked.
+void Htransmutated(int, bool HisD);
 public slots:
-void selectPSE(int index){selection=index; emit pseSelected(index);}//!< Change the current element by the program.
+void selectPSE(int index){
+    selection=index;
+//printf("PSE %d %d\n", index, QApplication::keyboardModifiers () == Qt::ShiftModifier);
+    emit pseSelected(index,QApplication::keyboardModifiers () == Qt::ShiftModifier);
+}//!< Change the current element by the program.
 void incFontSize();//!< Increase the font size of the Elements by one point.
 void decFontSize();//!< Decrease the font size of the Elements by one point.
 void colorchange(QColor bgcolor); //! Assign a new color to the current element.
+void probeShiftState();
 private:
 int sz; 
-Molecule mole;
+Molecule *mole;
+QSettings *einstellung;
 QToolButton *elebutt[109];
 QToolButton *lplus,*lminus;
 };
