@@ -111,8 +111,11 @@ void QPeakView::mousePressEvent ( QMouseEvent * event ){
     }
 }
 void QPeakView::wheelEvent ( QWheelEvent * event ){
-
+#if (QT_VERSION>0x050000)
+    double numSteps = event->angleDelta().y() / 12000.0;
+#else
     double numSteps = event->delta() / 12000.0;
+#endif
     if (event->modifiers()==Qt::NoModifier){
       double d = cutoff;
       cutoff=(d+numSteps>=(min-0.05))?d+numSteps:d;
