@@ -1,5 +1,8 @@
 #include "savehistorywidget.h"
 #include "deprecation.h"
+#include <QScrollArea>
+#include <QDialogButtonBox>
+#include <QSplitter>
 
 SaveHistoryWidget::SaveHistoryWidget(QString filename, bool _dark, QWidget *parent  ):QDialog(parent){
   pvindex=-1;
@@ -83,7 +86,7 @@ void SaveHistoryWidget::updatePreview(int index){
     pvindex=index;
     edi->setReadOnly(false);
     QString ext=dda->entries.at(index);
-    ext.remove(QRegExp("^\n"));
+    ext.remove(QRegularExpression("^\n"));
     edi->setPlainText(ext);
     edi->diffTo(orginal);
     edi->setReadOnly(true);
@@ -145,8 +148,8 @@ DragDropVersions::DragDropVersions(QString filename, bool d,QWidget *parent) :QW
           argument=filename.section('/',-1);
 
   QString insorres=argument;
-  if (insorres.endsWith("res",Qt::CaseInsensitive)) insorres.replace(QRegExp("res$",Qt::CaseInsensitive),"ins");
-  else if (insorres.endsWith("ins",Qt::CaseInsensitive)) insorres.replace(QRegExp("ins$",Qt::CaseInsensitive),"res");
+  if (insorres.endsWith("res",Qt::CaseInsensitive)) insorres.replace(QRegularExpression("res$", QRegularExpression::CaseInsensitiveOption),"ins");
+  else if (insorres.endsWith("ins",Qt::CaseInsensitive)) insorres.replace(QRegularExpression("ins$", QRegularExpression::CaseInsensitiveOption),"res");
   dark=d;
   current=-1;
   QString saveHistName=QString("%1/%2saves/SAVEHIST").arg(dn).arg(PROGRAM_NAME);
@@ -154,15 +157,16 @@ DragDropVersions::DragDropVersions(QString filename, bool d,QWidget *parent) :QW
   sahi.open(QIODevice::ReadOnly|QIODevice::Text);
   QString Alles=sahi.readAll();//Entry|@|2011-03-08T13:32:19|@|b11.res|@|
   sahi.close();
-  QRegExp re = QRegExp("Entry\\|@\\|\\w+-\\w+-\\w+:\\w+:\\w+\\|@\\|[^@]+@\\|");
+  QRegularExpression re = QRegularExpression("Entry\\|@\\|\\w+-\\w+-\\w+:\\w+:\\w+\\|@\\|[^@]+@\\|");
+  QRegularExpressionMatchIterator matchiterator = re.globalMatch(Alles);
   entries = Alles.split(re,skipEmptyParts);
-  int pos = re.indexIn(Alles);
   QStringList filenames;
-  while (pos>-1) {
-    zeiten.append(QDateTime::fromString(re.cap(0).section('|',2,2),Qt::ISODate));
-    filenames.append(re.cap(0).section('|',4,4));
-    re.indexIn(Alles,pos+30);
-    pos=re.pos(0);
+  while (matchiterator.hasNext()) {
+    QString recap0 = matchiterator.next().captured();
+    zeiten.append(QDateTime::fromString(recap0.section('|',2,2),Qt::ISODate));
+    filenames.append(recap0.section('|',4,4));
+    //re.indexIn(Alles,pos+30);
+    //pos=re.pos(0);
   }
   now = QDateTime::currentDateTime();
   for (int j=0; j<filenames.size(); j++)
@@ -185,7 +189,7 @@ DragDropVersions::DragDropVersions(QString filename, bool d,QWidget *parent) :QW
   hoehe = l->height()+25;
   x=lawi+5;
   for (int i=0; i<zeiten.size(); i++){
-    DragVersion *wordLabel = new DragVersion(i,zeiten.at(i).toString(),zeiten.at(i).toTime_t(),-1,dark , this);
+    DragVersion *wordLabel = new DragVersion(i,zeiten.at(i).toString(),zeiten.at(i).toSecsSinceEpoch(),-1,dark , this);
     wordLabel->move(x, y);
     wordLabel->show();
     wordLabel->setAttribute(Qt::WA_DeleteOnClose);
@@ -237,7 +241,7 @@ void DragDropVersions::tack(){
     }
     if ((idx<0)||(idx>=zeiten.size())||(child->secs()==666)) continue;
     //child->setText(seitkurzem(now.secsTo(QDateTime::fromTime_t (child->secs()))));
-    child->setText(QDateTime::fromTime_t (child->secs()).toString());
+    child->setText(QDateTime::fromSecsSinceEpoch(child->secs()).toString());
     if (dark)child->setStyleSheet (QString(
                       "QLabel{color: #ffffff; font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #242424);} "
                       "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
