@@ -22,17 +22,13 @@
 #include <QtGui>
 #include <QtNetwork>
 #include "chgl.h"
-#include "highlighter.h"
 #include "codeeditor.h"
-#include "eacDlg.h"
 #include "qpeakview.h"
 #include "psewidget.h"
-#include "dragdropatomsdlg.h"
 #include "historywidget.h"
-#include "savehistorywidget.h"
 #include "fourxle.h"
-#include "fcvsfo.h"
 #include "itsme.h"
+#include "opengltestwidget.h"
 #ifndef nullptr 
 #define nullptr NULL
 #endif
@@ -73,7 +69,8 @@
 class Window : public QMainWindow {
   Q_OBJECT
   public:
-    Window(ChGL *_chgl);
+    //Window(ChGL *_chgl);
+    Window(PlayOpenGL *_chgl=nullptr);
     virtual ~Window();
     //bool scroller;
     static int Version();//!< This return the actual Revision
@@ -83,7 +80,13 @@ class Window : public QMainWindow {
     int MaxNumberOfPeaks;
     int wght_max_cycls;
     static QString programName(){return QString(PROGRAM_NAME);}//!<get the actual programname
-    ChGL *chgl;
+    //ChGL *chgl = nullptr;
+    PlayOpenGL *chgl = nullptr;
+    PlayOpenGL *ogl;
+    OpenGLTestWidget *tgl = nullptr;
+    QTextEdit *extraOutPut;
+    CodeEditor *editor;
+    CodeEditor *xlPutor;
     QSettings *einstellung;
 #if (QT_VERSION >=0x050000)
     QScreen *screen;
@@ -95,10 +98,8 @@ class Window : public QMainWindow {
     QAction *openAct; 
     QAction *screenshotAct;
     QAction *objExport;
-    QAction *tubeStyle;
-    QAction *ballStyle;
     QAction *separateLabelFile;
-    QAction *toggleOrthoView;
+    //QAction *toggleOrthoView;
     QAction *belocube;
     QAction *actionUniq;
     QAction *actionSearch;
@@ -119,9 +120,9 @@ class Window : public QMainWindow {
     QAction *togAtom;
     QAction *togBond;
     QAction *togLabel;
-    QAction *togUnit;
-    QAction *togElli;
-    QAction *togHBond;
+    //QAction *togUnit;
+    //QAction *togElli;
+    //QAction *togHBond;
     QAction *togBackGr;
     QAction *togDepthCueing;
     QAction *actionPovRay;
@@ -171,12 +172,14 @@ class Window : public QMainWindow {
     QToolButton  *zoomOut;
     QToolButton  *homeMe;
     QToolButton *quickReLoadButton;
+    QSpinBox *lodsp;
     QCheckBox *sr_same;//use same restraint for part atoms
     QCheckBox *sr_simu;//use sumu restraint for part atoms
     QCheckBox *sr_rigu;//use rigu restarint for part atoms
     QCheckBox *sr_alter_name;//give alternataive name to 2nd part atoms
     QCheckBox *sr_ExyzAadp_ifclose; // apply EXYZ and EADP if atoms are very close
     bool notRefine;
+    bool shaderInfo = false;
     int tbiconSize;
     QHash<QString,QVariant> myHash;//!< This Hash connects recent file names with cursor positions. So that files are opened always at the same position.
     QAction *refineAct;
@@ -209,6 +212,23 @@ class Window : public QMainWindow {
     QSpinBox *lpart;
     QSpinBox *rpart;
     bool canWeSqueeze();
+    int cifCheckSum(const QString &block);
+
+    const QRegularExpression buchstaben = QRegularExpression("[A-Za-z]");
+    const QRegularExpression vorneweg = QRegularExpression("[^A-Za-z']+");
+    const QRegularExpression resorins = QRegularExpression("(.res$)|(.ins$)", QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression punkthkl = QRegularExpression(".hkl$",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression unitinst = QRegularExpression("^UNIT",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression punktres = QRegularExpression(".res$", QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression punktins = QRegularExpression(".ins$",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression punktpov = QRegularExpression("(.pov)",QRegularExpression::CaseInsensitiveOption);
+    const QRegularExpression leer = QRegularExpression("\\s+");
+    const QRegularExpression numbers = QRegularExpression("\\d+");
+    const QRegularExpression startnumbers = QRegularExpression("^[0-9]+");
+
+    const QRegularExpression nonumbers = QRegularExpression("\\D+");
+    const QRegularExpression commaspace = QRegularExpression(", $");
+
 
 signals:
     void fileLoaded(void);
@@ -216,6 +236,7 @@ signals:
     void movedByUser();
 
     public slots:
+    void loadMolInTest(bool fromloadref=false);
     void qinitres();
     void addNewScatteringFactor(int oz, bool HisD);//!<Adds a new scattering factor to the SFAC / UNIT list.
     void addDissorderedMethyl();//!<Adds rotation dissordered hydroghen atoms to a R-C carbon atom. (methyl group) AFIX 127.
@@ -236,9 +257,14 @@ signals:
     void changeEditorFont();//!<Changes the Editor font via an font dialog.
     void changeElemetofLabel(const QString &pse);//!<NextLabel of rename mode consists of labelPSE labelIndex labelSuffix, this changes the LabelPSE to pse. @param pse next labelPSE. 
     void changeElement();//!<Changes the element of an atom (chgl->ImeanThisAtom) to an other scattering factor (acation->data)
+    void changeSelectedElements();
     void changeIconSize();//!<Changes the size of the tool bar icons.
     void changeInvRad(double r);
-    void changePlaneTransparence(double t);
+    void changePlaneTransparence(double t);    
+    void changeglideVectorThickness(double t);
+    void changeaxisThickness(double t);
+    void changeplaneFrameThinkness(double t);
+
     void changeQPeakLimit();//!<Maximum number of Q-peaks created by addMoreQPeaks
     void changeIndexofLabel(const int i);//!<NextLabel of rename mode consists of labelPSE labelIndex labelSuffix, this changes the LabelIndex to pse. @param i next labelIndex. For i < 0 no number in label. 
     void changeLabelFont();//!<Changes the font of the on screen Labels of the atoms.
@@ -257,9 +283,10 @@ signals:
     void everyAIM();
     void contourPlot();
     void nocontourPlot();
+    void delayedLoad();
     void colorButtonDialog();
     void convergeWght();//!<Tries to refine until the wheighting scheme converges.
-    bool compareWGHTS(QString w1, QString w2, double tolerance = 0.001);//!<Compare 2 WGHT strings by value 
+    bool compareWGHTS(QString w1, QString w2, double &diff, double tolerance = 0.001);//!<Compare 2 WGHT strings by value
     void complete();//!<forces the display list to be updated. 
     void configureBottomToolbar();//!<Changes the look and feel and position of the Selection Tool Bar.
     void copySymmMate();//!<copies the fractional coordinates of a symmetry generated part -n atom in the file. 
@@ -295,6 +322,7 @@ signals:
     void go2hklf4();
     void grossRC(const QString &text);//!< Capitalizes the text and sets the resiResiClass text to text @param text new text for resiResiClass.
     void grow();//!< completes the molecule by symmetry.
+    void grow_plus();
     void growQPeaks(bool qpg);//!< applies symmetrie operations used for the main structure also for the Q-Peaks.
     void hereAreMyKeys();
     void hideToolz(bool b);//!< Hides all tool bars.
@@ -314,7 +342,7 @@ signals:
     void jumpToAtom(int index);//!< if rename mode is visible the atom at index gets renamed if not the cursor of the editor is pointed to the specified atom.
     void linkHelp();//!< Show a Link to the online help. 
     void loadAFile();//!< (re)loads the file specified in dirName.
-    void loadFile(QString fileName);//!< loads the file with the specified path the listfile is also loaded. @param fileName path to the res / ins file.
+    void loadFile(QString fileName, bool fromloadref=false);//!< loads the file with the specified path the listfile is also loaded. @param fileName path to the res / ins file.
     void load_sheldrick(QString fileName, QString &inhalt);//!< Loads a shelx file from a string. You have to take care that the file is valid beforehand.
     bool quickReLoad(QString fn, QString &cont);//!< Updates a structure after refinement or save With keeping grow and hide states unchanged. If differences are to large false is returned 1/19/2021
     void loadLst();//!< loads the .lst file if it exists.
@@ -377,6 +405,7 @@ signals:
     void shxOPTUpdate(bool vis);//!< the editor tool bar gets visible when the editor is visible.
     void sina();//!< ANIS backwards is SINA! makes specified, selected or all atoms isotrop again with uiso = 0.05
     //  void springSlider();
+    void testOGL();
     void  spellCheck();//!< a syntax check for the res file.
     void closeSR(bool vis);
     void splitRotate();
@@ -436,7 +465,7 @@ signals:
     void defineBarray();
   protected:
     void paintEvent(QPaintEvent *event);
-    void moveEvent(QMoveEvent *event);
+    //void moveEvent(QMoveEvent *event);
     void dragEnterEvent(QDragEnterEvent *event);
     void dropEvent(QDropEvent *event);
     void showEvent(QShowEvent * event);// override;
@@ -518,8 +547,6 @@ signals:
     double scalePic;
     QString saveName,fvarinfo;
     QProcess *shelxl,*extraProc;
-    QTextEdit *extraOutPut;
-    CodeEditor *editor , *xlPutor;
     QString shelxlPath, shelxlArgs;
     bool useMyBArray;    //! If set to true, the b-array is not automatically set by ShelXle
     QStringList extraProgramNames,extraProgramPaths,extraOptions,extraExt2;
